summaryrefslogtreecommitdiff
path: root/basctl/source
diff options
context:
space:
mode:
authorMichael T. Whiteley <mike@whiteley.org>2011-12-07 02:33:51 -0800
committerTor Lillqvist <tlillqvist@suse.com>2011-12-08 11:32:41 +0200
commitdcfd4beb213c551f6ef6ba379651bf303bd9017a (patch)
treea819f50716357c2a5561f6b9a09809cfc52d7dbf /basctl/source
parentad2eb6c4ba3ca36e2302c721a106dac80d266325 (diff)
childs -> children
Diffstat (limited to 'basctl/source')
-rw-r--r--basctl/source/basicide/baside2.hxx2
-rw-r--r--basctl/source/basicide/baside2b.cxx6
-rw-r--r--basctl/source/basicide/bastype2.hxx2
-rw-r--r--basctl/source/basicide/bastype3.cxx10
-rw-r--r--basctl/source/dlged/dlgedobj.cxx22
-rw-r--r--basctl/source/inc/dlgedobj.hxx4
6 files changed, 23 insertions, 23 deletions
diff --git a/basctl/source/basicide/baside2.hxx b/basctl/source/basicide/baside2.hxx
index e9378ab30a78..1804df9bf01f 100644
--- a/basctl/source/basicide/baside2.hxx
+++ b/basctl/source/basicide/baside2.hxx
@@ -225,7 +225,7 @@ public:
WatchTreeListBox( Window* pParent, WinBits nWinBits );
~WatchTreeListBox();
- void RequestingChilds( SvLBoxEntry * pParent );
+ void RequestingChildren( SvLBoxEntry * pParent );
void UpdateWatches( bool bBasicStopped = false );
using SvTabListBox::SetTabs;
diff --git a/basctl/source/basicide/baside2b.cxx b/basctl/source/basicide/baside2b.cxx
index dfef3853e02a..9b3ca10bba0c 100644
--- a/basctl/source/basicide/baside2b.cxx
+++ b/basctl/source/basicide/baside2b.cxx
@@ -1758,7 +1758,7 @@ void WatchTreeListBox::SetTabs()
}
}
-void WatchTreeListBox::RequestingChilds( SvLBoxEntry * pParent )
+void WatchTreeListBox::RequestingChildren( SvLBoxEntry * pParent )
{
if( !StarBASIC::IsRunning() )
return;
@@ -2070,12 +2070,12 @@ void implEnableChildren( SvLBoxEntry* pEntry, bool bEnable )
pEntry->SetFlags(
(pEntry->GetFlags() &
~(SV_ENTRYFLAG_NO_NODEBMP | SV_ENTRYFLAG_HAD_CHILDREN))
- | SV_ENTRYFLAG_CHILDS_ON_DEMAND );
+ | SV_ENTRYFLAG_CHILDREN_ON_DEMAND );
}
else
{
pEntry->SetFlags(
- (pEntry->GetFlags() & ~(SV_ENTRYFLAG_CHILDS_ON_DEMAND)) );
+ (pEntry->GetFlags() & ~(SV_ENTRYFLAG_CHILDREN_ON_DEMAND)) );
}
}
diff --git a/basctl/source/basicide/bastype2.hxx b/basctl/source/basicide/bastype2.hxx
index 645cbe0aea5e..6f1162774de1 100644
--- a/basctl/source/basicide/bastype2.hxx
+++ b/basctl/source/basicide/bastype2.hxx
@@ -159,7 +159,7 @@ private:
void SetEntryBitmaps( SvLBoxEntry * pEntry, const Image& rImage );
protected:
- virtual void RequestingChilds( SvLBoxEntry* pParent );
+ virtual void RequestingChildren( SvLBoxEntry* pParent );
virtual void ExpandedHdl();
virtual SvLBoxEntry* CloneEntry( SvLBoxEntry* pSource );
virtual long ExpandingHdl();
diff --git a/basctl/source/basicide/bastype3.cxx b/basctl/source/basicide/bastype3.cxx
index ab353b3c90a8..0edbddc65b88 100644
--- a/basctl/source/basicide/bastype3.cxx
+++ b/basctl/source/basicide/bastype3.cxx
@@ -50,11 +50,11 @@ using namespace ::com::sun::star;
typedef std::deque< SvLBoxEntry* > EntryArray;
-void BasicTreeListBox::RequestingChilds( SvLBoxEntry* pEntry )
+void BasicTreeListBox::RequestingChildren( SvLBoxEntry* pEntry )
{
BasicEntryDescriptor aDesc( GetEntryDescriptor( pEntry ) );
ScriptDocument aDocument( aDesc.GetDocument() );
- OSL_ENSURE( aDocument.isAlive(), "BasicTreeListBox::RequestingChilds: invalid document!" );
+ OSL_ENSURE( aDocument.isAlive(), "BasicTreeListBox::RequestingChildren: invalid document!" );
if ( !aDocument.isAlive() )
return;
@@ -124,7 +124,7 @@ void BasicTreeListBox::RequestingChilds( SvLBoxEntry* pEntry )
}
else
{
- OSL_FAIL( "BasicTreeListBox::RequestingChilds: Error loading library!" );
+ OSL_FAIL( "BasicTreeListBox::RequestingChildren: Error loading library!" );
}
}
}
@@ -137,7 +137,7 @@ void BasicTreeListBox::RequestingChilds( SvLBoxEntry* pEntry )
ImpCreateLibSubSubEntriesInVBAMode( pEntry, aDocument, aLibName );
}
else {
- OSL_FAIL( "BasicTreeListBox::RequestingChilds: Unknown Type!" );
+ OSL_FAIL( "BasicTreeListBox::RequestingChildren: Unknown Type!" );
}
}
@@ -146,7 +146,7 @@ void BasicTreeListBox::ExpandedHdl()
SvLBoxEntry* pEntry = GetHdlEntry();
DBG_ASSERT( pEntry, "Was wurde zugeklappt?" );
- if ( !IsExpanded( pEntry ) && pEntry->HasChildsOnDemand() )
+ if ( !IsExpanded( pEntry ) && pEntry->HasChildrenOnDemand() )
{
SvLBoxEntry* pChild = FirstChild( pEntry );
while ( pChild )
diff --git a/basctl/source/inc/dlgedobj.hxx b/basctl/source/inc/dlgedobj.hxx
index ebe1186dd43b..096a1e7d25a5 100644
--- a/basctl/source/inc/dlgedobj.hxx
+++ b/basctl/source/inc/dlgedobj.hxx
@@ -147,7 +147,7 @@ class DlgEdForm: public DlgEdObj
private:
DlgEditor* pDlgEditor;
- ::std::vector<DlgEdObj*> pChilds;
+ ::std::vector<DlgEdObj*> pChildren;
mutable ::boost::optional< ::com::sun::star::awt::DeviceInfo > mpDeviceInfo;
@@ -169,7 +169,7 @@ public:
virtual void AddChild( DlgEdObj* pDlgEdObj );
virtual void RemoveChild( DlgEdObj* pDlgEdObj );
- virtual ::std::vector<DlgEdObj*> GetChilds() const { return pChilds; }
+ virtual ::std::vector<DlgEdObj*> GetChildren() const { return pChildren; }
virtual void UpdateStep();
diff --git a/basctl/source/dlged/dlgedobj.cxx b/basctl/source/dlged/dlgedobj.cxx
index aa79ef1f5de8..eb06efe9b0d1 100644
--- a/basctl/source/dlged/dlgedobj.cxx
+++ b/basctl/source/dlged/dlgedobj.cxx
@@ -593,7 +593,7 @@ void DlgEdObj::TabIndexChange( const beans::PropertyChangeEvent& evt ) throw (Ru
if ( pForm )
{
// stop listening with all children
- ::std::vector<DlgEdObj*> aChildList = pForm->GetChilds();
+ ::std::vector<DlgEdObj*> aChildList = pForm->GetChildren();
::std::vector<DlgEdObj*>::iterator aIter;
for ( aIter = aChildList.begin() ; aIter != aChildList.end() ; ++aIter )
{
@@ -1428,14 +1428,14 @@ void DlgEdForm::SetPropsFromRect()
void DlgEdForm::AddChild( DlgEdObj* pDlgEdObj )
{
- pChilds.push_back( pDlgEdObj );
+ pChildren.push_back( pDlgEdObj );
}
//----------------------------------------------------------------------------
void DlgEdForm::RemoveChild( DlgEdObj* pDlgEdObj )
{
- pChilds.erase( ::std::find( pChilds.begin() , pChilds.end() , pDlgEdObj ) );
+ pChildren.erase( ::std::find( pChildren.begin() , pChildren.end() , pDlgEdObj ) );
}
//----------------------------------------------------------------------------
@@ -1500,7 +1500,7 @@ void DlgEdForm::PositionAndSizeChange( const beans::PropertyChangeEvent& evt )
bool bAdjustedPageSize = pEditor->AdjustPageSize();
SetRectFromProps();
::std::vector< DlgEdObj* >::iterator aIter;
- ::std::vector< DlgEdObj* > aChildList = ((DlgEdForm*)this)->GetChilds();
+ ::std::vector< DlgEdObj* > aChildList = ((DlgEdForm*)this)->GetChildren();
if ( bAdjustedPageSize )
{
@@ -1590,7 +1590,7 @@ void DlgEdForm::UpdateTabIndices()
{
// stop listening with all children
::std::vector<DlgEdObj*>::iterator aIter;
- for ( aIter = pChilds.begin() ; aIter != pChilds.end() ; ++aIter )
+ for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
{
(*aIter)->EndListening( sal_False );
}
@@ -1642,7 +1642,7 @@ void DlgEdForm::UpdateTabIndices()
}
// start listening with all children
- for ( aIter = pChilds.begin() ; aIter != pChilds.end() ; ++aIter )
+ for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
{
(*aIter)->StartListening();
}
@@ -1687,7 +1687,7 @@ void DlgEdForm::UpdateGroups()
if ( xTabModel.is() )
{
// create a global list of controls that belong to the dialog
- ::std::vector<DlgEdObj*> aChildList = GetChilds();
+ ::std::vector<DlgEdObj*> aChildList = GetChildren();
sal_uInt32 nSize = aChildList.size();
Sequence< Reference< awt::XControl > > aSeqControls( nSize );
for ( sal_uInt32 i = 0; i < nSize; ++i )
@@ -1757,9 +1757,9 @@ void DlgEdForm::NbcMove( const Size& rSize )
SetPropsFromRect();
StartListening();
// set geometry properties of all childs
::std::vector<DlgEdObj*>::iterator aIter;
- for ( aIter = pChilds.begin() ; aIter != pChilds.end() ; ++aIter )
+ for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
{
(*aIter)->EndListening(sal_False);
(*aIter)->SetPropsFromRect();
@@ -1781,9 +1781,9 @@ void DlgEdForm::NbcResize(const Point& rRef, const Fraction& xFract, const Fract
SetPropsFromRect();
StartListening();
// set geometry properties of all childs
::std::vector<DlgEdObj*>::iterator aIter;
- for ( aIter = pChilds.begin() ; aIter != pChilds.end() ; ++aIter )
+ for ( aIter = pChildren.begin() ; aIter != pChildren.end() ; ++aIter )
{
(*aIter)->EndListening(sal_False);
(*aIter)->SetPropsFromRect();
@@ -1757,9 +1757,9 @@ void DlgEdForm::NbcMove( const Size& rSize )
SetPropsFromRect();
StartListening();
- // set geometry properties of all childs
+ // set geometry properties of all children
::std::vector<DlgEdObj*>::iterator aIter;
@@ -1781,9 +1781,9 @@ void DlgEdForm::NbcResize(const Point& rRef, const Fraction& xFract, const Fract
SetPropsFromRect();
StartListening();
- // set geometry properties of all childs
+ // set geometry properties of all children
::std::vector<DlgEdObj*>::iterator aIter;